dice_ml.utils.serialize — DiCE 0.7 documentation

# Source code for dice_ml.utils.serialize

    class DummyDataInterface:
        def __init__(self, outcome_name, data_df=None):
            self.outcome_name = outcome_name
            if data_df is not None:
                self.data_df = data_df

        def to_json(self):
            return {
                'outcome_name': self.outcome_name,
                'data_df': self.data_df
            }